DPDK patches and discussions
 help / color / mirror / Atom feed
From: Hemant Agrawal <hemant.agrawal@nxp.com>
To: ferruh.yigit@intel.com
Cc: dev@dpdk.org, shreyansh.jain@nxp.com
Subject: [dpdk-dev] [PATCH 3/8] net/dpaa: fix the array overrun
Date: Thu,  5 Apr 2018 14:24:19 +0530	[thread overview]
Message-ID: <1522918464-4586-3-git-send-email-hemant.agrawal@nxp.com> (raw)
In-Reply-To: <1522918464-4586-1-git-send-email-hemant.agrawal@nxp.com>

Fixes: 62f53995caaf ("net/dpaa: add frame count based tail drop with CGR")
Coverity issue: 268342
Cc: stable@dpdk.org

Signed-off-by: Hemant Agrawal <hemant.agrawal@nxp.com>
---
 drivers/net/dpaa/dpaa_ethdev.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/net/dpaa/dpaa_ethdev.c b/drivers/net/dpaa/dpaa_ethdev.c
index db49364..0aad111 100644
--- a/drivers/net/dpaa/dpaa_ethdev.c
+++ b/drivers/net/dpaa/dpaa_ethdev.c
@@ -1105,10 +1105,10 @@ dpaa_dev_init(struct rte_eth_dev *eth_dev)
 			dpaa_push_mode_max_queue = DPAA_MAX_PUSH_MODE_QUEUE;
 	}
 
 	/* Each device can not have more than DPAA_PCD_FQID_MULTIPLIER RX
 	 * queues.
 	 */
-	if (num_rx_fqs <= 0 || num_rx_fqs > DPAA_PCD_FQID_MULTIPLIER) {
+	if (num_rx_fqs <= 0 || num_rx_fqs > DPAA_MAX_NUM_PCD_QUEUES) {
 		DPAA_PMD_ERR("Invalid number of RX queues\n");
 		return -EINVAL;
 	}
@@ -1105,10 +1105,10 @@ dpaa_dev_init(struct rte_eth_dev *eth_dev)
 	}
 
-	/* Each device can not have more than DPAA_PCD_FQID_MULTIPLIER RX
+	/* Each device can not have more than DPAA_MAX_NUM_PCD_QUEUES RX
 	 * queues.
 	 */
-- 
2.7.4

  parent reply	other threads:[~2018-04-05  8:56 UTC|newest]

Thread overview: 20+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2018-04-05  8:54 [dpdk-dev] [PATCH 1/8] bus/dpaa: fix the resource leak issue Hemant Agrawal
2018-04-05  8:54 ` [dpdk-dev] [PATCH 2/8] bus/dpaa: fix the unchecked return value Hemant Agrawal
2018-04-05  8:54 ` Hemant Agrawal [this message]
2018-04-09  5:29   ` [dpdk-dev] [PATCH 3/8] net/dpaa: fix the array overrun Shreyansh Jain
2018-04-05  8:54 ` [dpdk-dev] [PATCH 4/8] net/dpaa: fix the oob access Hemant Agrawal
2018-04-09  7:23   ` Shreyansh Jain
2018-04-05  8:54 ` [dpdk-dev] [PATCH 5/8] bus/dpaa: fix resource leak Hemant Agrawal
2018-04-09  7:18   ` Shreyansh Jain
2018-04-05  8:54 ` [dpdk-dev] [PATCH 6/8] net/dpaa: update checksum for external pool obj Hemant Agrawal
2018-04-05  8:54 ` [dpdk-dev] [PATCH 7/8] net/dpaa2: fix the implementation of xstats Hemant Agrawal
2018-04-05  8:54 ` [dpdk-dev] [PATCH 8/8] bus/fslmc: configure separate portal for Ethernet Rx Hemant Agrawal
2018-04-09 10:22 ` [dpdk-dev] [PATCH v2 1/8] bus/dpaa: fix the resource leak issue Hemant Agrawal
2018-04-09 10:22   ` [dpdk-dev] [PATCH v2 2/8] bus/dpaa: fix the unchecked return value Hemant Agrawal
2018-04-09 10:22   ` [dpdk-dev] [PATCH v2 3/8] net/dpaa: fix the array overrun Hemant Agrawal
2018-04-09 10:22   ` [dpdk-dev] [PATCH v2 4/8] net/dpaa: fix the oob access Hemant Agrawal
2018-04-09 10:22   ` [dpdk-dev] [PATCH v2 5/8] bus/dpaa: fix resource leak Hemant Agrawal
2018-04-09 10:22   ` [dpdk-dev] [PATCH v2 6/8] net/dpaa: update checksum for external pool obj Hemant Agrawal
2018-04-09 10:22   ` [dpdk-dev] [PATCH v2 7/8] net/dpaa2: fix the implementation of xstats Hemant Agrawal
2018-04-09 10:22   ` [dpdk-dev] [PATCH v2 8/8] bus/fslmc: configure separate portal for Ethernet Rx Hemant Agrawal
2018-04-11 22:20   ` [dpdk-dev] [PATCH v2 1/8] bus/dpaa: fix the resource leak issue Thomas Monjalon

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1522918464-4586-3-git-send-email-hemant.agrawal@nxp.com \
    --to=hemant.agrawal@nxp.com \
    --cc=dev@dpdk.org \
    --cc=ferruh.yigit@intel.com \
    --cc=shreyansh.jain@nxp.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).